@@ -24,6 +24,7 @@
 #include <kurlrequester.h>
 #include <kpassdlg.h>
 #include <kcombobox.h>
+#include <kdebug.h>
 #include <klineedit.h>
 #include <iostream>
 #include <qfile.h>
@@ -34,16 +35,15 @@
 #include "kvpncconfig.h"
 //END includes
 
-ImportCertificateDialog::ImportCertificateDialog( QWidget *parent, const QString& caption, KVpncConfig *GlobalConfig)
-		: KDialogBase( parent, i18n("Import certificate..."), true, caption,
-		KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true )
- {
+ImportCertificateDialog::ImportCertificateDialog( QWidget *parent, const char* caption, KVpncConfig *GlobalConfig)
+		: KDialogBase( parent, i18n("Import Certificate").ascii(), true, caption,
+		               KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true )
+{
 	main = new ImportCertificateDialogBase(this);
 	setMainWidget(main);
 	main->setMinimumSize(main->sizeHint());
 
-// FIXME make appendLogEntry accessable
-// 	this->GlobalConfig = GlobalConfig;
+	this->GlobalConfig = GlobalConfig;
 	filename = "";
 	certHash = "";
 	importOk = false;
@@ -66,15 +66,18 @@ ImportCertificateDialog::ImportCertificateDialog( QWidget *parent, const QString
 	main->ImporttypeComboBox->setCurrentItem( 1 );
 		main->PrivateKeyPasswordEdit->setText( "12345678" );
 		main->PrivateKeyAgainPasswordEdit->setText( "12345678" );
-	*/ 
+	*/
 	//main->ImportPasswordEdit->setText( "blah99" );
 
 
 }
 
-ImportCertificateDialog::~ImportCertificateDialog() {}
+ImportCertificateDialog::~ImportCertificateDialog()
+{}
+
+void ImportCertificateDialog::accept()
+{
 
-void ImportCertificateDialog::accept() {
 	importOk = true;
 	done=false;
 
@@ -82,114 +85,201 @@ void ImportCertificateDialog::accept() {
 	importpassword = main->ImportPasswordEdit->text();
 	certpath = main->RacoonCertificatePathUrlrequester->url();
 
-	if ( filename.isEmpty() ) {
-		KMessageBox::sorry( 0, i18n( "Filename can't be empty!" ), i18n( "Empty filename" ) );
+	if ( filename.isEmpty() )
+	{
+		KMessageBox::sorry( 0, i18n( "File name cannot be empty!" ), i18n( "Empty File Name" ) );
 		importOk = false;
 		importSuccess=false;
 		return;
 	}
 
-// 	if ( filename.right( 3 ) != "p12" || filename.right (3) != "der" || filename.right (3) != "crt" ) {
-// 		KMessageBox::sorry( 0, i18n( "Filename isnt ended by \'p12\', 'der' or \'crt\'!" ), i18n( "Wrong filename" ) );
-// 		importOk = false;
-// 		return;
-// 	}
+	// 	if ( filename.right( 3 ) != "p12" || filename.right (3) != "der" || filename.right (3) != "crt" ) {
+	// 		KMessageBox::sorry( 0, i18n( "File name isnt ended by \'p12\', 'der' or \'crt\'!" ), i18n( "Wrong File Name" ) );
+	// 		importOk = false;
+	// 		return;
+	// 	}
 
 	QFile f( filename );
-	if ( f.exists() ) {
-		if ( f.open( IO_ReadOnly ) ) {
+	if ( f.exists() )
+	{
+		if ( f.open( IO_ReadOnly ) )
+		{
 			f.close();
-		} else {
-			KMessageBox::sorry( 0, i18n( "File does not exist!" ), i18n( "No file" ) );
+		}
+		else
+		{
+			KMessageBox::sorry( 0, i18n( "File does not exist!" ), i18n( "No File" ) );
+			GlobalConfig->appendLogEntry ( i18n( "Certificate import: file \"%1\" does not exist." ).arg( filename ),GlobalConfig->error );
+
 			importOk = false;
 			return;
 		}
-	} else {
-		KMessageBox::sorry( 0, i18n( "File not readable!" ), i18n( "insufficient rights" ) );
+	}
+	else
+	{
+		KMessageBox::sorry( 0, i18n( "File not readable!" ), i18n( "Insufficient Rights" ) );
+
+		GlobalConfig->appendLogEntry ( i18n( "Certificate import: file \"%1\" is not readable." ).arg( filename ),GlobalConfig->error );
 		importOk = false;
 		return;
 	}
 
+	if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan )
+	{
+		if ( !QDir("/etc/ipsec.d").exists())
+		{
+			if (!QDir().mkdir("/etc/ipsec.d"))
+			{
+				KMessageBox::error( this, i18n( "\"%1\" could not be created!" ).arg( "/etc/ipsec.d" ) );
+				GlobalConfig->appendLogEntry ( i18n( "Certificate import: directory \"%1\" does not exist and could not be created." ).arg( "/etc/ipsec.d" ),GlobalConfig->error );
+			}
+			else
+			{
+				if (GlobalConfig->KvpncDebugLevel > 0 )
+					GlobalConfig->appendLogEntry ( i18n( "Certificate import: directory \"%1\" does not exist but was successful created." ).arg( "/etc/ipsec.d" ),GlobalConfig->debug );
+				if ( !QDir("/etc/ipsec.d/certs").exists())
+				{
+					if (!QDir().mkdir("/etc/ipsec.d/certs"))
+					{
+						KMessageBox::error( this, i18n( "\"%1\" could not be created!" ).arg( "/etc/ipsec.d/certs" ) );
+						GlobalConfig->appendLogEntry ( i18n( "Certificate import: directory \"%1\" does not exist and could not be created." ).arg("/etc/ipsec.d/certs" ),GlobalConfig->error );
+					}
+					else
+					{
+						GlobalConfig->appendLogEntry ( i18n( "Certificate import: directory \"%1\" does not exist but was successful created." ).arg( "/etc/ipsec.d/certs" ),GlobalConfig->debug );
+						if ( !QDir("/etc/ipsec.d/cacerts").exists())
+							if (!QDir().mkdir("/etc/ipsec.d/cacerts"))
+							{
+								KMessageBox::error( this, i18n( "\"%1\" could not be created!" ).arg( "/etc/ipsec.d/cacerts" ) );
+								GlobalConfig->appendLogEntry ( i18n( "Certificate import: directory \"%1\" does not exist and could not  be created." ).arg( "/etc/ipsec.d/cacerts" ),GlobalConfig->error );
+							}
+							else
+							{
+								if (GlobalConfig->KvpncDebugLevel > 0 )
+									GlobalConfig->appendLogEntry ( i18n( "Certificate import: directory \"%1\" does not exist but was successful created." ).arg( "/etc/ipsec.d/cacerts" ),GlobalConfig->debug );
+							}
+					}
+				}
+			}
+		}
+	}
+	else if ( main->ImporttypeComboBox->currentItem() == pkcs12_racoon || main->ImporttypeComboBox->currentItem() == ca_der )
+	{
+		if ( !QDir(certpath).exists())
+			if (!QDir().mkdir(certpath))
+			{
+				KMessageBox::error( this, i18n( "\"%1\" could not be created!" ).arg( certpath ) );
+				GlobalConfig->appendLogEntry ( i18n( "Certificate import: directory \"%1\" does not exist." ).arg( certpath ),GlobalConfig->error );
+			}
+			else
+			{
+				if (GlobalConfig->KvpncDebugLevel > 0 )
+					GlobalConfig->appendLogEntry ( i18n( "Certificate import: directory \"%1\" does not exist but was successful created." ).arg( certpath ),GlobalConfig->debug );
+			}
+	}
+
+
 	if ( (main->ImporttypeComboBox->currentItem() == pkcs12_freeswan ||
-				main->ImporttypeComboBox->currentItem() == pkcs12_racoon ) &&
-				importpassword.isEmpty() ) {
+	        main->ImporttypeComboBox->currentItem() == pkcs12_racoon ) &&
+	        importpassword.isEmpty() )
+	{
 		importOk = false;
-		KMessageBox::sorry( 0, i18n( "Password can't be empty!" ), i18n( "Empty password" ) );
+		KMessageBox::sorry( 0, i18n( "Password can't be empty!" ), i18n( "Empty Password" ) );
 		return;
 	}
 
-	if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan ) {
-		if ( main->PrivateKeyPasswordEdit->text().isEmpty() || main->PrivateKeyPasswordEdit->text().length() < 4 ) {
+	if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan )
+	{
+		if ( main->PrivateKeyPasswordEdit->text().isEmpty() || main->PrivateKeyPasswordEdit->text().length() < 4  )
+		{
 			importOk = false;
-			KMessageBox::sorry( 0, i18n( "Private key password field can not be empty or less than 4 characters!" ), i18n( "password empty or too short" ) );
+			KMessageBox::sorry( 0, i18n( "Private key password field can not be empty or less than 4 characters!" ), i18n( "Password Empty or Too Short" ) );
 			return;
 		}
 
-		if ( main->PrivateKeyAgainPasswordEdit->text().isEmpty() || main->PrivateKeyAgainPasswordEdit->text().length() < 4 ) {
+		if ( main->PrivateKeyAgainPasswordEdit->text().isEmpty() || main->PrivateKeyAgainPasswordEdit->text().length() < 4 )
+		{
 			importOk = false;
-			KMessageBox::sorry( 0, i18n( "Private key password (again) field can not be empty!" ), i18n( "password empty or too short" ) );
+			KMessageBox::sorry( 0, i18n( "Private key password (again) field can not be empty!" ), i18n( "Password Empty or Too Short" ) );
 			return;
 		}
-		if ( importOk ) {
-			if ( main->PrivateKeyPasswordEdit->text() != main->PrivateKeyAgainPasswordEdit->text() ) {
+		if ( importOk )
+		{
+			if ( main->PrivateKeyPasswordEdit->text() != main->PrivateKeyAgainPasswordEdit->text() )
+			{
 				importOk = false;
-				KMessageBox::sorry( 0, i18n( "Private key passwords does not match!" ), i18n( "passwords do not match" ) );
+				KMessageBox::sorry( 0, i18n( "Private key passwords does not match!" ), i18n( "Passwords Do Not Match" ) );
 				return;
 			}
 		}
 	}
 
 	if (GlobalConfig->KvpncDebugLevel > 0 )
-		std::cout << "file: " << filename << ", type: " << main->ImporttypeComboBox->currentItem() << std::endl;
+		kdDebug() << "file: " << filename << ", type: " << main->ImporttypeComboBox->currentItem() << endl;
 
 	// looking for openssl
-	if ( pathToOpenSSL.isEmpty() ) {
-		QFile openssl( "/usr/sbin/openssl" );
-		if ( openssl.exists() )
-			pathToOpenSSL = "/usr/sbin/openssl";
-		else {
-			openssl.setName( "/usr/local/sbin/openssl" );
-			if ( openssl.exists() )
-				pathToOpenSSL = "/usr/local/sbin/openssl";
-			else {
-				openssl.setName( "/usr/bin/openssl" );
-				if ( openssl.exists() )
-					pathToOpenSSL = "/usr/bin/openssl";
-				else {
-					KMessageBox::error( this, i18n( "Unable to find \"%1\"!" ).arg("openssl") );
-					GlobalConfig->appendLogEntry(i18n( "Unable to find \"%1\"!" ).arg("openssl") ,GlobalConfig->error);
-					importOk = false;
+	bool found=true;
+	QString bin="openssl";
+	ToolInfo *tool;
+	//std::cout << "Tool (bin): " << bin << std::endl;
+	if (!GlobalConfig->ToolList->isEmpty())
+	{
+		for ( tool = GlobalConfig->ToolList->first(); tool; tool = GlobalConfig->ToolList->next() )
+		{
+			if (bin == tool->Name)
+			{
+				if (tool->PathToExec.section('/',-1) != bin )
+				{
+					// program is NOT installed
+					KMessageBox::error ( this, i18n( "The required tool (%1) is not installed, please install it first and restart kvpnc.").arg(bin), i18n( "Tool Missing" ) );
+					found=false;
 				}
+				break;
 			}
 		}
 	}
 
+	if( !found)
+	{
+		KMessageBox::error( this, i18n( "Unable to find \"%1\"!" ).arg("openssl") );
+		GlobalConfig->appendLogEntry(i18n( "Unable to find \"%1\"!" ).arg("openssl") ,GlobalConfig->error);
+		importOk = false;
+	}
+
+
 	QString file = QUrl ( filename ).fileName();
 	certName = file.left( file.length() - 4 ); // peter_pan.p12 -> peter_pan
 
-	if ( main->ImporttypeComboBox->currentItem() == pkcs12_racoon ) {
+	if ( main->ImporttypeComboBox->currentItem()
+	        == pkcs12_racoon )
+	{
 		QFile certpathtest( certpath + "/." );
 
-		if ( !certpathtest.exists() ) {
-			KMessageBox::error( this, i18n( "racoon certificate path (%1) doesnt exist!" ).arg( certpath ) );
-			GlobalConfig->appendLogEntry(i18n( "racoon certificate path (%1) doesnt exist!" ).arg( certpath ) ,GlobalConfig->error);
+		if ( !certpathtest.exists() )
+		{
+			KMessageBox::error( this, i18n( "racoon certificate path (%1) does not exist!" ).arg( certpath ) );
+			GlobalConfig->appendLogEntry(i18n( "racoon certificate path (%1) does not exist!" ).arg( certpath ) ,GlobalConfig->error);
 			importOk=false;
-		} else {
+		}
+		else
+		{
 			QFile testfile ( QString(certpath + "/test" ));
-			if ( !testfile.open( IO_WriteOnly ) ) {
-				KMessageBox::error( this, i18n( "racoon certificate path (%1) isnt writeable!" ).arg( certpath ) );
-				GlobalConfig->appendLogEntry(i18n( "racoon certificate path (%1) isnt writeable!" ).arg( certpath )  ,GlobalConfig->error);
+			if ( !testfile.open( IO_WriteOnly ) )
+			{
+				KMessageBox::error( this, i18n( "racoon certificate path (%1) is not writeable!" ).arg( certpath ) );
+				GlobalConfig->appendLogEntry(i18n( "racoon certificate path (%1) is not writeable!" ).arg( certpath )  ,GlobalConfig->error);
 				importOk = false;
 			}
-			else {
+			else
+			{
 				testfile.remove();
 			}
 		}
 	}
 
-
 	// here we go
-	if ( importOk ) {
+	if ( importOk )
+	{
 
 		/*
 		FreeSWAN/Racoon:
@@ -201,20 +291,23 @@ void ImportCertificateDialog::accept() {
 		*/
 		// 		 		std::cout << "[std]:" << "settings ok." << std::endl;
 
-		ImportProcess = new QProcess( this );
+		ImportProcess = new QProcess( this )
+		                ;
 		ImportProcess->addArgument( pathToOpenSSL );
 
 		if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan ||
-			main->ImporttypeComboBox->currentItem() == pkcs12_racoon
-		) {
-		ImportProcess->addArgument( "pkcs12" );
-		ImportProcess->addArgument( "-in" );
-		ImportProcess->addArgument( filename );
-		ImportProcess->addArgument( "-nodes" );
-		ImportProcess->addArgument( "-clcerts" );
-		ImportProcess->addArgument( "-out" );
+		        main->ImporttypeComboBox->currentItem() == pkcs12_racoon
+		   )
+		{
+			ImportProcess->addArgument( "pkcs12" );
+			ImportProcess->addArgument( "-in" );
+			ImportProcess->addArgument( filename );
+			ImportProcess->addArgument( "-nodes" );
+			ImportProcess->addArgument( "-clcerts" );
+			ImportProcess->addArgument( "-out" );
 		}
-		else if ( main->ImporttypeComboBox->currentItem() == ca_der ){
+		else if ( main->ImporttypeComboBox->currentItem() == ca_der )
+		{
 			ImportProcess->addArgument( "x509" );
 			ImportProcess->addArgument( "-in" );
 			ImportProcess->addArgument( filename );
@@ -223,10 +316,12 @@ void ImportCertificateDialog::accept() {
 			ImportProcess->addArgument( "-inform" );
 			ImportProcess->addArgument( "DER" );
 		}
-		if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan ) {
+		if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan )
+		{
 			ImportProcess->addArgument( "/etc/ipsec.d/certs/mykeys_" + certName + ".pem" ); // warning: static
 		}
-		else if( main->ImporttypeComboBox->currentItem() == pkcs12_racoon ){
+		else if( main->ImporttypeComboBox->currentItem() == pkcs12_racoon )
+		{
 			ImportProcess->addArgument( certpath + "/mykeys_" + certName + ".pem" );
 		}
 
@@ -234,41 +329,93 @@ void ImportCertificateDialog::accept() {
 		connect( ImportProcess, SIGNAL( readyReadStdout() ), this, SLOT( readFromStdout_import() ) );
 		connect( ImportProcess, SIGNAL( readyReadStderr() ), this, SLOT( readFromStderr_import() ) );
 		if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan ||
-			main->ImporttypeComboBox->currentItem() == pkcs12_racoon
-		) {
+		        main->ImporttypeComboBox->currentItem() == pkcs12_racoon
+		   )
+		{
 			connect( ImportProcess, SIGNAL( processExited () ), this, SLOT( doCacert() ) );
 		}
-		if ( main->ImporttypeComboBox->currentItem() == ca_der) {
+		if ( main->ImporttypeComboBox->currentItem() == ca_der)
+		{
 			connect( ImportProcess, SIGNAL( processExited () ), this, SLOT( doCreateHash() ) );
 		}
 
-		if ( !ImportProcess->start() ) {
+		if ( !ImportProcess->start() )
+		{
 			KMessageBox::sorry( this, i18n( "Unable to start process (%1)!" ).arg("openssl") );
-		} else {
-			// ok
-			//std::cout << "[std]:" << " openssl started." << std::endl;
+		}
+		else
+		{
+			if (GlobalConfig->KvpncDebugLevel > 0 )
+				GlobalConfig->appendLogEntry ( i18n( "Process (%1) started." ).arg( "openssl" ),GlobalConfig->debug );
 		}
 	}
-	
-	
 }
-
-void ImportCertificateDialog::canAccept() {
-// 	// FIXME
-// 	while (ImportProcess->isRunning() && !done)
-// 		sleep (1);
-
+void ImportCertificateDialog::canAccept()
+{
 	if (importSuccess)
-		KMessageBox::information( 0, i18n( "Certificate was sucessfully imported." ), i18n( "import successful" ) );
+	{
+		KMessageBox::information( 0, i18n( "Certificate was sucessfully imported." ), i18n( "Import Successful" ) );
+		if (GlobalConfig->KvpncDebugLevel > 0 )
+			GlobalConfig->appendLogEntry ( i18n( "Certificate import: certificate was successfully imported." ),GlobalConfig->debug );
+	}
 	else
-		KMessageBox::sorry( 0, i18n( "Certificate import failed." ), i18n( "import failed" ) );
+	{
+		KMessageBox::sorry( 0, i18n( "Certificate import failed." ), i18n( "Import Failed" ) );
+		GlobalConfig->appendLogEntry ( i18n( "Certificate import: certificate could not be imported." ),GlobalConfig->error );
+	}
+
+	if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan)
+	{
+		QString bin="ipsec";
+		ToolInfo *tool;
+		//std::cout << "Tool (bin): " << bin << std::endl;
+		if (!GlobalConfig->ToolList->isEmpty())
+		{
+			for ( tool = GlobalConfig->ToolList->first(); tool; tool = GlobalConfig->ToolList->next() )
+			{
+				if (bin == tool->Name)
+				{
+					if (tool->PathToExec.section('/',-1) != bin )
+					{
+						// program is NOT installed
+						KMessageBox::information ( this, i18n( "The required tool (%1) is not installed, please install it before you are connecting and restart kvpnc.").arg(bin), i18n( "Tool Missing" ) );
+					}
+					break;
+				}
+			}
+		}
+	}
+	else if ( main->ImporttypeComboBox->currentItem() == pkcs12_racoon)
+	{
+		QString bin="racoon";
+		ToolInfo *tool;
+		//std::cout << "Tool (bin): " << bin << std::endl;
+		if (!GlobalConfig->ToolList->isEmpty())
+		{
+			for ( tool = GlobalConfig->ToolList->first(); tool; tool = GlobalConfig->ToolList->next() )
+			{
+				if (bin == tool->Name)
+				{
+					if (tool->PathToExec.section('/',-1) != bin )
+					{
+						// program is NOT installed
+						KMessageBox::information ( this, i18n( "The required tool (%1) is not installed, please install it before you are connecting and restart kvpnc.").arg(bin), i18n( "Tool Missing" ) );
+					}
+					break;
+				}
+			}
+		}
+	}
 
 	QDialog::accept();
 }
 
-void ImportCertificateDialog::doCacert() {
-	if ( ImportProcess->normalExit () ) {
-		//	LogOutput->append("[dbg]: doCacert()");
+void ImportCertificateDialog::doCacert()
+{
+	if ( ImportProcess->normalExit () )
+	{
+		if (GlobalConfig->KvpncDebugLevel > 0 )
+			GlobalConfig->appendLogEntry ( i18n( "Certificate import: doCacert()" ),GlobalConfig->debug );
 		disconnect( ImportProcess, SIGNAL( processExited () ), this, SLOT( doCacert() ) );
 		/*
 		openssl pkcs12 -in cert.p12 -nokeys -cacerts -out /etc/racoon/certs/ca_company.pem -nodes
@@ -293,18 +440,22 @@ void ImportCertificateDialog::doCacert() {
 
 		if (! ImportProcess->start() )
 		{
-			KMessageBox::error( 0, i18n( "Unable to extract CA certificate!" ), i18n( "extract failed" ) );
+			KMessageBox::error( 0, i18n( "Unable to extract CA certificate!" ), i18n( "Extract Failed" ) );
+			GlobalConfig->appendLogEntry ( i18n( "Certificate import: CA certificate could not be extracted." ),GlobalConfig->error );
 			importSuccess=false;
 		}
-		else {
-
+		else
+		{
+			if (GlobalConfig->KvpncDebugLevel > 0 )
+				GlobalConfig->appendLogEntry ( i18n( "Certificate import: CA certificate successful extracted." ),GlobalConfig->debug );
 		}
-
 	}
 }
 
-void ImportCertificateDialog::doPrivateKey() {
-	if ( ImportProcess->normalExit () ) {
+void ImportCertificateDialog::doPrivateKey()
+{
+	if ( ImportProcess->normalExit () )
+	{
 		//	LogOutput->append("[dbg]: doPrivateKey()");
 		disconnect( ImportProcess, SIGNAL( processExited () ), this, SLOT( doPrivateKey() ) );
 		/*
@@ -322,19 +473,21 @@ void ImportCertificateDialog::doPrivateKey() {
 		connect( ImportProcess, SIGNAL( processExited () ), this, SLOT( exit() ) );
 
 		//LogOutput->append( "priv key: we starting..." );
-		if ( !ImportProcess->start( ) ) {
+		if ( !ImportProcess->start( ) )
+		{
 			KMessageBox::sorry( this, i18n( "Unable to start process (private key)!" ) );
 			importSuccess=false;
 		}
-		else {
-		}
+		else
+		{}
 
 	}
 }
 
-
-void ImportCertificateDialog::doCreateHash() {
-	if ( ImportProcess->normalExit () ) {
+void ImportCertificateDialog::doCreateHash()
+{
+	if ( ImportProcess->normalExit () )
+	{
 
 		disconnect( ImportProcess, SIGNAL( processExited () ), this, SLOT( doCreateHash() ) );
 
@@ -356,17 +509,22 @@ void ImportCertificateDialog::doCreateHash() {
 
 
 		//		LogOutput->append( "hash: we starting..." );
-		if ( !ImportProcess->start( ) ) {
+		if ( !ImportProcess->start( ) )
+		{
 			KMessageBox::sorry( this, i18n( "Unable to start process (%1)!" ).arg("hash") );
 			importSuccess=false;
-		} else {
+		}
+		else
+		{
 			doHash = true;
 		}
 	}
 }
 
-void ImportCertificateDialog::doLink() {
-	if ( ImportProcess->normalExit () ) {
+void ImportCertificateDialog::doLink()
+{
+	if ( ImportProcess->normalExit () )
+	{
 		disconnect( ImportProcess, SIGNAL( processExited () ), this, SLOT( doLink() ) );
 		doHash = false;
 		ImportProcess->clearArguments();
@@ -375,10 +533,13 @@ void ImportCertificateDialog::doLink() {
 		*/
 		ImportProcess->addArgument( "ln" );
 		ImportProcess->addArgument( "-s" );
-		if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan ) {
+		if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan )
+		{
 			ImportProcess->addArgument( certpath+"/cacerts/ca_" + certName + ".pem" );
 			ImportProcess->addArgument( certpath+"/cacerts/" + certHash + ".0" );
-		} else {
+		}
+		else
+		{
 			ImportProcess->addArgument( certpath + "/ca_" + certName + ".pem" );
 			ImportProcess->addArgument( certpath + certHash + ".0" );
 		}
@@ -389,71 +550,85 @@ void ImportCertificateDialog::doLink() {
 			connect( ImportProcess, SIGNAL( processExited () ), this, SLOT( exit() ) );
 
 
-		if ( !ImportProcess->start( ) ) {
+		if ( !ImportProcess->start( ) )
+		{
 			KMessageBox::sorry( this, i18n( "Unable to start process (%1)!" ).arg("ln -s") );
 			importSuccess=false;
 		}
-		else {
-			
-		}
+		else
+		{}
 	}
 }
 
-void ImportCertificateDialog::exit() {
-// 	if ( ImportProcess->normalExit() )
-// 		importOk=true;
+void ImportCertificateDialog::exit()
+{
+	// 	if ( ImportProcess->normalExit() )
+	// 		importOk=true;
 	done=true;
 	canAccept();
 }
 
-void ImportCertificateDialog::readFromStdout_import() {
+void ImportCertificateDialog::readFromStdout_import()
+{
 	QString line = QString( ImportProcess->readStdout() );
 
-// FIXME make appendLogEntry accessable
-// 	LogOutput->append( "<font color=\"red\">[std]: " + line + "</font>" );
-	if ( doHash ) {
+	if (GlobalConfig->KvpncDebugLevel > 0 )
+		GlobalConfig->appendLogEntry ( i18n( "Certificate import stdout: %1" ).arg( line ),GlobalConfig->debug );
+	if ( doHash )
+	{
 		certHash = line.left( line.length() - 1 );
 		doHash = false;
 		//		LogOutput->append( "<font color=\"red\">[std]: hash" + line + "</font>" );
 	}
 
-	if ( line.find( "Enter Import Pass" , 0, FALSE ) > -1 ) {
+	if ( line.find( "Enter Import Pass" , 0, FALSE ) > -1 )
+	{
+		if (GlobalConfig->KvpncDebugLevel > 0 )
+			GlobalConfig->appendLogEntry ( i18n( "Certificate import: %1 was requested, send it..." ).arg(i18n(" import password")),GlobalConfig->debug );
 
-// FIXME make appendLogEntry accessable
-// 		LogOutput->append( "<font color=\"green\">[in]: write the password</font>" );
 		ImportProcess->writeToStdin( importpassword + "\n" );
 	}
 
-	if ( line.find( "Enter PEM pass phrase" , 0, FALSE ) > -1 ) {
+	if ( line.find( "Enter PEM pass phrase" , 0, FALSE ) > -1 )
+	{
 
-// FIXME make appendLogEntry accessable
-// 		LogOutput->append( "<font color=\"green\">[in]: write the private key password</font>" );
+		if (GlobalConfig->KvpncDebugLevel > 0 )
+			GlobalConfig->appendLogEntry ( i18n( "Certificate import: %1 was requested, send it..." ).arg(i18n("private key password")),GlobalConfig->debug );
 		ImportProcess->writeToStdin( main->PrivateKeyPasswordEdit->text() + "\n" );
 	}
 
 }
 
-void ImportCertificateDialog::readFromStderr_import() {
+void ImportCertificateDialog::readFromStderr_import()
+{
 	QString line = QString( ImportProcess->readStderr() );
 
-// FIXME make appendLogEntry accessable
-// 	LogOutput->append( "<font color=\"black\">[err]: " + line + "</font>" );
-
-	if ( line.find( "invalid password" , 0, FALSE ) > -1 ) {
-		KMessageBox::sorry( 0, i18n( "wrong password?!." ), i18n( "password failed" ) );
+	if (line.find("Error",9, FALSE ) > -1 )
+	{
+		GlobalConfig->appendLogEntry ( i18n( "Certificate import: %2" ).arg(line),GlobalConfig->error );
+		importSuccess=false;
 	}
 
-	if ( line.find( "Enter Import Pass", 0, FALSE ) > -1 ) {
+	if ( line.find( "invalid password" , 0, FALSE ) > -1 )
+	{
+		KMessageBox::sorry( 0, i18n( "Wrong password." ), i18n( "Password Failed" ) );
+		GlobalConfig->appendLogEntry ( i18n( "Certificate import: password was invalid" ),GlobalConfig->error );
+		importSuccess=false;
+	}
 
-// FIXME make appendLogEntry accessable
-// 		LogOutput->append( "<font color=\"green\">[in]: write the password</font>" );
+	if ( line.find( "Enter Import Pass", 0, FALSE ) > -1 )
+	{
+
+		if (GlobalConfig->KvpncDebugLevel > 0 )
+			GlobalConfig->appendLogEntry ( i18n( "Certificate import: %1 was requested, send it..." ).arg(i18n("import password")),GlobalConfig->debug );
 		ImportProcess->writeToStdin( importpassword + "\n" );
 	}
 
-	if ( line.find( "Enter PEM pass phrase", 0, FALSE ) > -1 ) {
+	if ( line.find( "Enter PEM pass phrase", 0, FALSE ) > -1 )
+	{
 
-// FIXME make appendLogEntry accessable
-// 		LogOutput->append( "<font color=\"green\">[in]: write the private key password</font>" );
+		if (GlobalConfig->KvpncDebugLevel > 0 )
+			GlobalConfig->appendLogEntry ( i18n( "Certificate import: password was requested, send it..." ).arg(i18n("private key password")),GlobalConfig->debug );
 		ImportProcess->writeToStdin( main->PrivateKeyPasswordEdit->text() + "\n" );
 	}
 
@@ -461,24 +636,28 @@ void ImportCertificateDialog::readFromStderr_import() {
 	// 		LogOutput->append( "<font color=\"green\">[in]: write the private key password (again)</font>" );
 	// 		ImportProcess->writeToStdin( importpassword + "\n" );
 	// 	}
-	if ( line.find( "unable to  certificate", 0, FALSE ) > -1 ) {
-		KMessageBox::error( 0, i18n( "Unable to load certificate!" ), i18n( "load failed" ) );
+	if ( line.find( "unable to load certificate", 0, FALSE ) > -1 )
+	{
+		KMessageBox::error( 0, i18n( "Unable to load certificate!" ), i18n( "Load Failed" ) );
 		GlobalConfig->appendLogEntry( i18n( "Unable to load certificate!" ) ,GlobalConfig->error);
 		importOk=true;
 		importSuccess=false;
-		if (ImportProcess->isRunning()){
+		if (ImportProcess->isRunning())
+		{
 			ImportProcess->kill();
 		}
 		done=true;
 	}
-	
+
 
 
 }
 
-void ImportCertificateDialog::typeToggeled( int type ) {
+void ImportCertificateDialog::typeToggeled( int type )
+{
 	//std::cout << "type: " << type << std::endl;
-	if ( type == pkcs12_freeswan ) {
+	if ( type == pkcs12_freeswan )
+	{
 		certpath = "/etc/ipsec.d/certs";
 		main->PrivateKeyPasswordEdit->setEnabled( true );
 		main->PrivateKeyAgainPasswordEdit->setEnabled( true );
@@ -488,7 +667,8 @@ void ImportCertificateDialog::typeToggeled( int type ) {
 		main->FreeswanGroupBox->setEnabled( true );
 		main->FilenameUrlrequester->setFilter( "*.p12" );
 	}
-	else if ( type == pkcs12_racoon ) {
+	else if ( type == pkcs12_racoon )
+	{
 		certpath = "/etc/racoon/certs/";
 		main->PrivateKeyPasswordEdit->setEnabled( false );
 		main->PrivateKeyAgainPasswordEdit->setEnabled( false );
@@ -498,7 +678,8 @@ void ImportCertificateDialog::typeToggeled( int type ) {
 		main->FreeswanGroupBox->setEnabled( false );
 		main->FilenameUrlrequester->setFilter( "*.p12" );
 	}
-	else if ( type == ca_der ) {
+	else if ( type == ca_der )
+	{
 		certpath = "/etc/certs/";
 		main->PrivateKeyPasswordEdit->setEnabled( false );
 		main->PrivateKeyAgainPasswordEdit->setEnabled( false );
