@@ -169,6 +169,7 @@ class KVpnc : public KMainWindow , DCOPObject
 		bool X509CertificateExtractUser;
 		bool setVirtualIPSuccess;
 		bool AuthRetry;
+		bool quitFromKicker;
 
 		QString OldDefaultroute;
 		QString VpncConnectScript;
@@ -202,6 +203,8 @@ class KVpnc : public KMainWindow , DCOPObject
 		QProcess *X509CertificateExtractProcess;
 		QProcess *PptpProcess;
 		QProcess *OpenvpnProcess;
+		QProcess *CmdBeforeConnectProcess;
+		QProcess *CmdBeforeDisconnectProcess;
 		QProcess *CmdAfterConnectProcess;
 		QProcess *CmdAfterDisconnectProcess;
 		QProcess *RouteProcess;
@@ -220,9 +223,8 @@ class KVpnc : public KMainWindow , DCOPObject
 		QPixmap *connectedStatusPixmap;
 
 		QLabel *statusColorLabel;
-
-		
 		QPopupMenu *QuickConnectMenu;
+
 	
 	public slots:
 		/** setup KVpnc */
@@ -259,6 +261,7 @@ class KVpnc : public KMainWindow , DCOPObject
 
 	private:
 		KApplication *parent;
+		QStringList *env;
 
 	private slots:
 		/**
@@ -295,6 +298,7 @@ class KVpnc : public KMainWindow , DCOPObject
 		void readFromStdout_connectionStatusCheck();
 		void readFromStderr_connectionStatusCheck();
 		void quitCalled();
+		void quitCalledKicker();
 		void advancedSettingsClicked();
 		void importProfileClicked();
 		void doRacoon();
@@ -333,6 +337,8 @@ class KVpnc : public KMainWindow , DCOPObject
 		void doQuickConnect(int id);
 		void startConnectionStatusCheck();
 		void generateOpenvpnKey();
+		void preserveNetworkEnvironment(); //< save route and resolv.conf
+		void restoreNetworkEnvironment(); //< restore route and resolv.conf
 	
 public:
 k_dcop:
