@@ -38,6 +38,9 @@ KVpncConfig::KVpncConfig()
 	pathToKillall="";
 	pathToPing="";
 	pathToOpenvpn="";
+	pathToIp="/sbin/ip";
+	pathToIfconfig="/sbin/ifconfig";
+	pathToRoute="/sbin/route";
 	AutoConnectProfile="";
 	Vpnc_pid_file = "";
 	Pppd_pid_file = "";
@@ -80,7 +83,7 @@ KVpncConfig::KVpncConfig()
 
 	ToolList = new QPtrList<ToolInfo>();
 	ToolList->setAutoDelete( TRUE );
-	ToolList = Utils().getToolList();
+	ToolList = Utils(this).getToolList();
 	getToolsInfo();
 
 	AccountList = new QPtrList<VpnAccountData>();
@@ -93,9 +96,8 @@ KVpncConfig::KVpncConfig()
 
 	KStandardDirs *dirs = KGlobal::dirs();
 	logfileName = QString(dirs->saveLocation( "data" ));
-	QString logfileName = logfileName;
-	logfileName += "/kvpnc/kvpnc.log";
-	logfile.setName( logfileName );
+	QString logfilePath = QString(logfileName + "/kvpnc/kvpnc.log");
+	logfile.setName( logfilePath );
 	logFileStream.setDevice( &logfile );
 
 	currentProfile=0L;
@@ -136,6 +138,8 @@ void KVpncConfig::appendLogEntry( QString msg, LogType type )
 
 		if (logfile.isOpen())
 		{
+			QString date = QDate().currentDate().toString(Qt::ISODate)+ " ";
+			QString time = QTime().currentTime().toString(Qt::ISODate)+ " ";
 			QString prefix="";
 			switch ( type )
 			{
@@ -155,11 +159,11 @@ void KVpncConfig::appendLogEntry( QString msg, LogType type )
 					prefix=i18n("debug")+": ";
 					break;
 			}
-			logFileStream << prefix << msg << "\n";
+			logFileStream << date << time << prefix << msg << "\n";
 		}
 
 
-		// write into debug console
+		// write into debug console 
 		QString prefix="";
 		QString postfix="";
 
@@ -252,6 +256,9 @@ void KVpncConfig::saveOptions()
 	config->writeEntry( "Path to kill-all", pathToKillall );
 	config->writeEntry( "Path to ping", pathToPing );
 	config->writeEntry( "Path to openvpn", pathToOpenvpn );
+	config->writeEntry( "Path to iputility", pathToIp );
+	config->writeEntry( "Path to ifconfig", pathToIfconfig );
+	config->writeEntry( "Path to route", pathToRoute );
 	config->writeEntry( "Show Statusbar", showStatusBar );
 	config->writeEntry( "Try connect timeout", tryConnectTimeout );
 	config->writeEntry( "Last Profile", lastProfile );
@@ -483,6 +490,7 @@ void KVpncConfig::saveOptions()
 				config->writeEntry( "Command before disconnect", it->getCommandBeforeDisconnect() );
 				config->writeEntry( "Command after disconnect", it->getCommandAfterDisconnect() );
 				config->writeEntry( "Use no BSD compression", it->getUseNoBsdComp() );
+				config->writeEntry( "Do not use no IP by default", it->getUseNoIpDefault());
 				config->writeEntry( "Use no deflate", it->getUseNoDeflate() );
 				config->writeEntry( "Set default route", it->getSetDefaultRoute() );
 				config->writeEntry( "Replace default route", it->getReplaceDefaultRoute() );
@@ -502,8 +510,10 @@ void KVpncConfig::saveOptions()
 				config->writeEntry( "Use connection status check", it->getUseConnectionStatusCheck() );
 				config->writeEntry( "Connection check success count", it->getConnectionStatusCheckSuccessCount() );
 				config->writeEntry( "Connection check status interval", it->getConnectionStatusInterval() );
-				config->writeEntry("Do reconnect after connection lost", it->getDoReconnectAfterConnectionLost());
-				config->writeEntry("Disable LZO compression", it->getDisableLzoCompression());
+				config->writeEntry( "Do reconnect after connection lost", it->getDoReconnectAfterConnectionLost());
+				config->writeEntry( "Disable LZO compression", it->getDisableLzoCompression());
+				config->writeEntry( "AuthWithUsernameAndPassword", it->getAuthWithUsernameAndPassword() );
+				config->writeEntry( "AllowEmptyGroupPassword", it->getAllowEmptyGroupPassword() );
 
 				QString AdditionalNetworkRoutesString;
 				QStringList AdditionalNetworkRoutes = it->getAdditionalNetworkRoutes();
@@ -551,6 +561,9 @@ void KVpncConfig::loadOptions()
 	pathToIptables = config->readEntry( "Path to iptables", "/sbin/iptables" );
 	pathToOpenssl = config->readEntry( "Path to openssl", "/usr/bin/openssl" );
 	pathToFreeswan = config->readEntry( "Path to freeswan", "/usr/sbin/ipsec" );
+	pathToIp = config->readEntry( "Path to iputility", "/sbin/ip" );
+	pathToIfconfig = config->readEntry( "Path to ifconfig", "/sbin/ifconfig" );
+	pathToRoute = config->readEntry( "Path to route", "/sbin/route" );
 	pathToPppd = config->readEntry ("Path to pppd","/usr/sbin/pppd");
 	pathToKill = config->readEntry ("Path to kill","/bin/kill");
 	pathToKillall = config->readEntry ("Path to kill-all","/usr/bin/killall");
@@ -657,7 +670,7 @@ void KVpncConfig::loadOptions()
 
 			if ( KvpncDebugLevel > 0 )
 			{
-				QString tmp = i18n( i18n( "Profile found: " ) );
+				QString tmp = i18n( "Profile found: " );
 				tmp += name.right( ( name.length() ) - 8 );
 				appendLogEntry ( tmp, debug );
 			}
@@ -799,6 +812,7 @@ void KVpncConfig::loadOptions()
 			data->setRequireMppe( config->readBoolEntry( "require mppe", true ));
 			data->setRefuseEap( config->readBoolEntry( "refuse EAP", false ));
 			data->setUseNoBsdComp( config->readBoolEntry( "Use no BSD compression", true ));
+			data->setUseNoIpDefault(config->readBoolEntry( "Do not use no IP by default", false));
 			data->setUseNoDeflate( config->readBoolEntry( "Use no deflate", true ));
 			data->setDisableMPPEComp( config->readBoolEntry( "Disable MPPE compression", false ));
 			data->setLocalVirtualIP( config->readEntry( "Local virtual IP", "" ));
@@ -840,6 +854,10 @@ void KVpncConfig::loadOptions()
 			data->setRemoteNet( RemoteNetAddr + "/" + QString().setNum( RemoteNetMask ) );
 			data->setPreSharedKey( PreSharedKey );
 			data->setPrivateKeyPass( PrivateKeyPass );
+			data->setAuthWithUsernameAndPassword( config->readBoolEntry( "AuthWithUsernameAndPassword",false ) );
+			data->setAllowEmptyGroupPassword( config->readBoolEntry( "AllowEmptyGroupPassword", false ) );
+
+
 			AccountList->append( data );
 
 			//ConnType, Name, Gateway, ID, GroupPassword, Username, UserPassword, saveUserPassword, saveGroupPassword, ApplicationVersion, Port, NtDomainName, PerfectForwardSecrecy, IkeGroup, useApplicationVersion, useGlobalIpsecSecret, useIkeGroup, useLocalPort, useNtDomainName, useSingleDes, useAdvancedSettings ) );
@@ -973,6 +991,24 @@ void KVpncConfig::getToolsInfo()
 					it->addSearchPath(pathToPing);
 				it->collectToolInfo();
 			}
+			else	if (it->Name == "ip")
+			{
+				if (!pathToIp.isEmpty())
+					it->addSearchPath(pathToIp);
+				it->collectToolInfo();
+			}
+			else	if (it->Name == "ifconfig")
+			{
+				if (!pathToIfconfig.isEmpty())
+					it->addSearchPath(pathToIfconfig);
+				it->collectToolInfo();
+			}
+			else	if (it->Name == "route")
+			{
+				if (!pathToRoute.isEmpty())
+					it->addSearchPath(pathToRoute);
+				it->collectToolInfo();
+			}
 			else
 			{
 				std::cout << "Invalid tool!" << std::endl;
@@ -1190,6 +1226,8 @@ void KVpncConfig::removeEntry(QString Name)
 					config->deleteEntry( "Keep default route" );
 
 					config->deleteEntry( "Additional network routes" );
+					config->deleteEntry("AuthWithUsernameAndPassword" );
+					config->deleteEntry("AllowEmptyGroupPassword" );
 
 					config->deleteGroup( ProfileName );
 
