@@ -45,10 +45,9 @@
 //END includes
 
 NewProfileDialog::NewProfileDialog( QApplication *app,QWidget *parent, const QString& caption, KVpncConfig *GlobalConfig)
-		: KDialogBase( parent, i18n("New profile"), true, caption,
+		: KDialogBase( parent, "New_profile", true, caption,
 		               KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true )
 {
-
 	this->GlobalConfig = GlobalConfig;
 
 	main = new NewProfileDialogbase(this);
@@ -91,14 +90,13 @@ NewProfileDialog::NewProfileDialog( QApplication *app,QWidget *parent, const QSt
 	savePsk = false;
 	useUdp=false;
 	useUdpPort=false;
-	UdpPort=4500;
 	useDnsServer=false;
 	DnsServer="";
 	useGetDnsFromPeer=true;
-	refuse40BitEncryption=false;
+	refuse40BitEncryption=true;
 	refuse128BitEncryption=false;
 	allowStatefulMode=false;
-	requireMppe=false;
+	requireMppe=true;
 	refuseEap=false;
 	useNoBsdComp=true;
 	useNoDeflate=true;
@@ -129,7 +127,7 @@ NewProfileDialog::NewProfileDialog( QApplication *app,QWidget *parent, const QSt
 
 
 
-	NetworkInterface iface(app);
+	NetworkInterface iface(GlobalConfig,app);
 	QStringList list = iface.getAllNetworkInterfaces();
 	main->NetworkDeviceComboBox->insertItem( "default" );
 	for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it )
@@ -158,8 +156,10 @@ NewProfileDialog::~NewProfileDialog()
 void NewProfileDialog::accept()
 {
 	bool canSave = TRUE;
-	if ( main->ConnectionTypeComboBox->currentItem() == 0 )
+	if ( main->ConnectionTypeComboBox->currentItem() == 0 ) {
 		profileData->setConnectionType( VpnAccountData::cisco );
+		UdpPort=10000;
+}
 	else if ( main->ConnectionTypeComboBox->currentItem() == 1 )
 	{
 		profileData->setConnectionType( VpnAccountData::racoon );
@@ -172,10 +172,12 @@ void NewProfileDialog::accept()
 		profileData->setX509Certificate( main->x509certURLRequester->url() );
 		profileData->setCertPath( main->certpathURLRequester->url() );
 
+		UdpPort=4500;
 	}
 	else if ( main->ConnectionTypeComboBox->currentItem() == 2 )
 	{
 		profileData->setConnectionType( VpnAccountData::freeswan );
+		UdpPort=4500;
 	}
 	else if ( main->ConnectionTypeComboBox->currentItem() == 3 )
 	{
@@ -194,16 +196,16 @@ void NewProfileDialog::accept()
 	{
 		if ( main->RemoteNetAddrLineEdit->text().contains( '.' ) != 3 )
 		{
-			KMessageBox::error ( this, i18n( "No IP address for remote network entered!" ), i18n( "No IP address" ) );
+			KMessageBox::error ( this, i18n( "No IP address for remote network entered!" ), i18n( "No IP Address" ) );
 			GlobalConfig->appendLogEntry(  i18n( "No IP address for remote network entered!" ),GlobalConfig->error);
 			validAddr = canSave = FALSE;
 		}
 		else
 		{
-			if (!Utils().isValidIPv4Adress(main->RemoteNetAddrLineEdit->text()))
+			if (!Utils(GlobalConfig).isValidIPv4Adress(main->RemoteNetAddrLineEdit->text()))
 			{
 
-				KMessageBox::error ( this, i18n( "IP address of remote network is not valid!" ), i18n( "Invalid IP address" ) );
+				KMessageBox::error ( this, i18n( "IP address of remote network is not valid!" ), i18n( "Invalid IP Address" ) );
 				GlobalConfig->appendLogEntry( i18n( "IP address of remote network not valid!" ) ,GlobalConfig->error);
 
 				validAddr = canSave = FALSE;
@@ -260,7 +262,7 @@ void NewProfileDialog::accept()
 
 		if (Name.contains(' '))
 		{
-			KMessageBox::error ( this, i18n( "Profile name can not contain spaces!" ), i18n( "Spaces not allowed" ) );
+			KMessageBox::error ( this, i18n( "Profile name can not contain spaces!" ), i18n( "Spaces Not Allowed" ) );
 			GlobalConfig->appendLogEntry( i18n( "Profile name can not contain spaces!" ) ,GlobalConfig->error);
 
 			nameOk = FALSE;
@@ -268,7 +270,7 @@ void NewProfileDialog::accept()
 
 		if (Name.isEmpty())
 		{
-			KMessageBox::error ( this, i18n( "Profile name can not be empty!" ), i18n( "No name entered" ) );
+			KMessageBox::error ( this, i18n( "Profile name can not be empty!" ), i18n( "No Name Entered" ) );
 			GlobalConfig->appendLogEntry( i18n( "Profile name can not be empty!" ) ,GlobalConfig->error);
 
 			nameOk = FALSE;
@@ -279,7 +281,7 @@ void NewProfileDialog::accept()
 		{
 			if ( it->getName() == Name )
 			{
-				KMessageBox::error ( this, i18n( "Profile name already exists!" ), i18n( "Name already exist" ) );
+				KMessageBox::error ( this, i18n( "Profile name already exists!" ), i18n( "Name Already Exists" ) );
 				GlobalConfig->appendLogEntry(i18n( "Profile name already exists!" ) ,GlobalConfig->error);
 
 				nameOk = FALSE;
@@ -301,7 +303,7 @@ void NewProfileDialog::accept()
 void NewProfileDialog::importCertificate()
 {
 	//FIXME make dynamiclly
-	ImportCertificateDialog importdlg(  this, i18n("Import certificate..."), GlobalConfig);
+	ImportCertificateDialog importdlg(  this, i18n("Import certificate...").ascii(), GlobalConfig);
 	//int result =
 	importdlg.exec();
 }
@@ -516,7 +518,7 @@ void NewProfileDialog::connectiontypeChanged( const QString& )
 		//buttonCancel->setEnabled( TRUE );
 		//buttonOk->setEnabled( TRUE );
 		main->AdvancedSettingsPushButton->setEnabled( TRUE );
-	} // racoon
+	} // pptp
 	else if ( item == VpnAccountData::ConnectionType(VpnAccountData::openvpn) )
 	{
 		if (GlobalConfig->KvpncDebugLevel > 0)
@@ -646,7 +648,7 @@ void NewProfileDialog::advancedSettingsClicked()
 	else
 		connectionType = VpnAccountData::ConnectionType(VpnAccountData::other);
 
-	AdvancedSettingsDialog d1(this, i18n("Advanced settings..."),profileData,connectionType,GlobalConfig);
+	AdvancedSettingsDialog d1(this, i18n("Advanced Settings"),profileData,connectionType,GlobalConfig);
 
 	d1.main->UseGlobalIpsecSecretCheckbox->setChecked ( profileData->getUseGlobalIpsecSecret() );
 	d1.main->SingleDesCheckbox->setChecked( profileData->getUseSpecialRemoteID() );
@@ -727,7 +729,7 @@ QString NewProfileDialog::getName()
 
 void NewProfileDialog::importPcfFileClicked()
 {
-	ImportProfileDialog dlg(this, i18n("Import Cisco PCF profile..."));
+	ImportProfileDialog dlg(GlobalConfig,this, i18n("Import Cisco PCF Profile..."));
 	dlg.exec();
 }
 
