@@ -127,7 +127,7 @@ ProfileWidget::ProfileWidget(  KVpncConfig *GlobalConfig, QWidget * parent, cons
 	}
 
 
-	NetworkInterface iface(GlobalConfig->appPointer);
+	NetworkInterface iface(GlobalConfig,GlobalConfig->appPointer);
 	QStringList list = iface.getAllNetworkInterfaces();
 	NetworkDeviceComboBox->insertItem( "default" );
 	for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it )
@@ -140,10 +140,10 @@ ProfileWidget::ProfileWidget(  KVpncConfig *GlobalConfig, QWidget * parent, cons
 	if ( GlobalConfig->currentProfile != 0 )
 	{
 		if ( GlobalConfig->currentProfile->getAuthType() == VpnAccountData::cert )
-			AuthTypeComboBox->setCurrentText( i18n( "X.509 certificate" ) );
+			AuthTypeComboBox->setCurrentText( i18n( "X.509 Certificate" ) );
 
 		if ( GlobalConfig->currentProfile->getAuthType() == VpnAccountData::psk )
-			AuthTypeComboBox->setCurrentText( i18n( "Pre shared key" ) );
+			AuthTypeComboBox->setCurrentText( i18n( "Pre Shared Key" ) );
 
 		if (GlobalConfig->currentProfile->getConnectionType() != VpnAccountData::ConnectionType(VpnAccountData::openvpn))
 			PSKLineEdit->setText( GlobalConfig->currentProfile->getPreSharedKey() );
@@ -224,7 +224,7 @@ ProfileWidget::~ProfileWidget()
 void ProfileWidget::importCertificate()
 {
 	//FIXME make path dynamiclly
-	ImportCertificateDialog dlg( this, i18n("Import certificate..."),GlobalConfig );
+	ImportCertificateDialog dlg( this, i18n("Import Certificate...").ascii(),GlobalConfig );
 	//int result =
 	dlg.exec();
 }
@@ -624,7 +624,7 @@ if ( GlobalConfig->KvpncDebugLevel > 0 )
 
 		connectionTypeChanged( ConnectionTypeComboBox->currentItem() );
 		AuthTypeComboBox->setCurrentItem(it->getAuthType());
-		x509certURLRequester->setFilter( "*.pem" );
+		x509certURLRequester->setFilter( "*.pem *.crt" );
 		certpathURLRequester->setMode( KFile::Directory );
 	}
 }
@@ -918,7 +918,7 @@ void ProfileWidget::newSessionClicked()
 {
 
 	// call new profile dialog...
- 	NewProfileDialog newdlg( GlobalConfig->appPointer,this, i18n("New profile"),GlobalConfig);
+ 	NewProfileDialog newdlg( GlobalConfig->appPointer,this, i18n("New Profile"),GlobalConfig);
 	newdlg.exec();
 	if ( newdlg.newProfileCreated )
 	{
@@ -946,7 +946,7 @@ void ProfileWidget::newSessionClicked()
 		GeneralGroupbox->setEnabled( true );
 		CommandExecutionGroupBox->setEnabled( true );
 
-		KMessageBox::information ( this, i18n( "Profile \"%1\" added.\nNow set the right type,\n fill in the fields\nand press \"Save\" to complete the profile." ).arg( Name ), i18n( "Complete profile" ) );
+		KMessageBox::information ( this, i18n( "Profile \"%1\" added.\nNow set the right type,\n fill in the fields\nand press \"Save\" to complete the profile." ).arg( Name ), i18n( "Complete Profile" ) );
 		//slotStatusMsg ( i18n( "Profile \"%1\" added." ).arg( Name ), ID_FLASH_MSG );
 
 		GlobalConfig->appendLogEntry ( i18n( "Profile \"%1\" added." ).arg( Name ),GlobalConfig->debug );
@@ -1016,7 +1016,7 @@ void ProfileWidget::saveSessionClicked()
 		bool validAddr = true;
 		if ( PingCheckBox->isChecked() && RemoteNetAddrLineEdit->text().contains( '.' ) != 3 )
 		{
-			KMessageBox::error ( this, i18n( "No IP address entered!" ), i18n( "No IP address" ) );
+			KMessageBox::error ( this, i18n( "No IP address entered!" ), i18n( "No IP Address" ) );
 			GlobalConfig->appendLogEntry(i18n( "No IP address entered!" ) ,GlobalConfig->error);
 			validAddr = false;
 		}
@@ -1036,7 +1036,7 @@ void ProfileWidget::saveSessionClicked()
 			*/
 			if ( ( part0 < 1 || part0 > 254 ) || ( part1 < 0 || part1 > 254 ) || ( part2 < 0 || part2 > 254 ) || ( part3 < 0 || part3 > 254 ) )
 			{
-				KMessageBox::error ( this, i18n( "IP address (remote net) is not valid!" ), i18n( "Invalid IP address" ) );
+				KMessageBox::error ( this, i18n( "IP address (remote net) is not valid!" ), i18n( "Invalid IP Address" ) );
 				GlobalConfig->appendLogEntry( i18n( "IP address (remote net) is not valid!" ) ,GlobalConfig->error);
 
 				validAddr = false;
@@ -1081,7 +1081,7 @@ void ProfileWidget::saveSessionClicked()
 		{
 			if ( RemoteNetAddrLineEdit->text().contains( '.' ) != 3 )
 			{
-				//KMessageBox::error ( this, i18n( "No IP address entered!" ), i18n( "No IP address" ) );
+				//KMessageBox::error ( this, i18n( "No IP address entered!" ), i18n( "No IP Address" ) );
 				validAddr = false;
 			}
 			else
@@ -1102,7 +1102,7 @@ void ProfileWidget::saveSessionClicked()
 				if ( ( part0 < 1 || part0 > 254 ) || ( part1 < 0 || part1 > 254 ) || ( part2 < 0 || part2 > 254 ) || ( part3 < 0 || part3 > 254 ) )
 				{
 					KMessageBox::error ( this, i18n( "Invalid values in IP address (remote net)!" ), i18n( "Invalid values in IP address" ) );
-					GlobalConfig->appendLogEntry(i18n( "Invalid values in IP address (remote net)!" ) ,GlobalConfig->error);
+					GlobalConfig->appendLogEntry(i18n( "Invalid Values in IP Address (remote net)!" ) ,GlobalConfig->error);
 					validAddr = false;
 				}
 
@@ -1128,7 +1128,7 @@ void ProfileWidget::saveSessionClicked()
 		bool validAddr = true;
 		if ( PingCheckBox->isChecked() && RemoteNetAddrLineEdit->text().contains( '.' ) != 3 )
 		{
-			KMessageBox::error ( this, i18n( "No IP address entered!" ), i18n( "No IP address" ) );
+			KMessageBox::error ( this, i18n( "No IP address entered!" ), i18n( "No IP Address" ) );
 			GlobalConfig->appendLogEntry(i18n( "No IP address entered!" ) ,GlobalConfig->error);
 			validAddr = false;
 		}
@@ -1148,7 +1148,7 @@ void ProfileWidget::saveSessionClicked()
 			*/
 			if ( ( part0 < 1 || part0 > 254 ) || ( part1 < 0 || part1 > 254 ) || ( part2 < 0 || part2 > 254 ) || ( part3 < 0 || part3 > 254 ) )
 			{
-				KMessageBox::error ( this, i18n( "IP address (remote net) is invalid!" ), i18n( "Invalid IP address" ) );
+				KMessageBox::error ( this, i18n( "IP address (remote net) is invalid!" ), i18n( "Invalid IP Address" ) );
 				GlobalConfig->appendLogEntry(i18n( "IP address (remote net) is invalid!" ) ,GlobalConfig->error);
 				validAddr = false;
 			}
@@ -1160,16 +1160,16 @@ void ProfileWidget::saveSessionClicked()
 		}
 
 		// 		QString LocalVirtualIp = LocalVirtualIpEdit->text();
-		// 		if (Utils().isValidIPv4Adress(LocalVirtualIp) == false)
-		// 			KMessageBox::error ( this, i18n( "No valid IP address entered!" ), i18n( "No valid IP address" ) );
+		// 		if (Utils( GlobalConfig ).isValidIPv4Adress(LocalVirtualIp) == false)
+		// 			KMessageBox::error ( this, i18n( "No valid IP address entered!" ), i18n( "No Valid IP Address" ) );
 		// 		else
 		// 		{
 		// 			GlobalConfig->currentProfile->setLocalVirtualIP( LocalVirtualIp);
 		// 		}
 		//
 		// 		QString RemoteVirtualIp = RemoteVirtualIpLineEdit->text();
-		// 		if (Utils().isValidIPv4Adress(RemoteVirtualIp) == false)
-		// 			KMessageBox::error ( this, i18n( "No valid IP address entered!" ), i18n( "No valid IP address" ) );
+		// 		if (Utils( GlobalConfig ).isValidIPv4Adress(RemoteVirtualIp) == false)
+		// 			KMessageBox::error ( this, i18n( "No valid IP address entered!" ), i18n( "No Valid IP Address" ) );
 		// 		else
 		// 		{
 		// 			GlobalConfig->currentProfile->setRemoteVirtualIP( RemoteVirtualIp);
@@ -1201,8 +1201,8 @@ void ProfileWidget::saveSessionClicked()
 	if ( PingCheckBox->isChecked() && !PingIPLineEdit->text().isEmpty() )
 	{
 		// do check for vailid IP
-		if (!Utils().isValidIPv4Adress(PingIPLineEdit->text())) {
-			KMessageBox::error ( this, i18n( "No valid IP address entered!" ), i18n( "No valid IP address" ) );
+		if (!Utils( GlobalConfig ).isValidIPv4Adress(PingIPLineEdit->text())) {
+			KMessageBox::error ( this, i18n( "No valid IP address entered!" ), i18n( "No Valid IP Address" ) );
 			GlobalConfig->appendLogEntry( i18n( "No valid IP address entered!" ) ,GlobalConfig->error);
 		}
 		else
@@ -1214,7 +1214,7 @@ void ProfileWidget::saveSessionClicked()
 	else
 	{
 		if ( PingCheckBox->isChecked() && PingIPLineEdit->text() == QString( "" ) ) {
-			KMessageBox::error ( this, i18n( "No IP address (ping host) entered!" ), i18n( "No IP address" ) );
+			KMessageBox::error ( this, i18n( "No IP address (ping host) entered!" ), i18n( "No IP Address" ) );
 			GlobalConfig->appendLogEntry(i18n( "No IP address (ping host) entered!" ) ,GlobalConfig->error);
 		}
 		else
@@ -1228,8 +1228,8 @@ void ProfileWidget::saveSessionClicked()
 		if ( UseVirtualIPCheckBox->isChecked() && !LocalVirtualIpEdit->text().isEmpty() )
 		{
 			// do check for vailid IP
-			if (!Utils().isValidIPv4Adress(LocalVirtualIpEdit->text())) {
-				KMessageBox::error ( this, i18n( "No valid IP address entered!" ), i18n( "No valid IP address" ) );
+			if (!Utils( GlobalConfig ).isValidIPv4Adress(LocalVirtualIpEdit->text())) {
+				KMessageBox::error ( this, i18n( "No valid IP address entered!" ), i18n( "No Valid IP Address" ) );
 				GlobalConfig->appendLogEntry( i18n( "No valid IP address entered!" ) ,GlobalConfig->error);
 			}
 			else
@@ -1241,7 +1241,7 @@ void ProfileWidget::saveSessionClicked()
 		else
 		{
 			if ( UseVirtualIPCheckBox->isChecked() && LocalVirtualIpEdit->text().isEmpty() ) {
-				KMessageBox::error ( this, i18n( "No IP address (virtual IP) entered!" ), i18n( "No IP address" ) );
+				KMessageBox::error ( this, i18n( "No IP address (virtual IP) entered!" ), i18n( "No IP Address" ) );
 				GlobalConfig->appendLogEntry(i18n( "No IP address (virtual IP) entered!" ) ,GlobalConfig->error);
 			}
 			else
@@ -1330,7 +1330,7 @@ void ProfileWidget::saveSessionClicked()
 		if (!SpecialServerCertificateURLRequester->url().isEmpty())
 			GlobalConfig->currentProfile->setSpecialServerCertificate(SpecialServerCertificateURLRequester->url());
 		else {
-			KMessageBox::error ( this, i18n( "Special server certificate can't be empty!" ), i18n( "No server certificate" ) );
+			KMessageBox::error ( this, i18n( "Special server certificate can't be empty!" ), i18n( "No Server Certificate" ) );
 			GlobalConfig->appendLogEntry( i18n( "Special server certificate can't be empty!" ) ,GlobalConfig->error);
 		}
 	}
@@ -1364,7 +1364,7 @@ void ProfileWidget::deleteSessionClicked()
 	QString Name = ProfileComboBox->currentText();
 	if ( !ProfileComboBox->currentText().isEmpty() )
 	{
-		int result = KMessageBox::questionYesNo ( this, i18n( "Really delete \"%1\"?" ).arg( Name ), i18n( "Delete?" ) );
+		int result = KMessageBox::questionYesNo ( this, i18n( "Really delete \"%1\"?" ).arg( Name ), i18n( "Delete?" ), KStdGuiItem::del(), KStdGuiItem::cancel() );
 		//LogOutput->append( "Result: "+ QString().setNum(result) ) ;
 		if ( result == 3) // Yes
 		{
@@ -1579,7 +1579,7 @@ void ProfileWidget::renameSessionClicked()
 {
 	bool ok=false;
 	QString oldName= GlobalConfig->currentProfile->getName();
-	QString newName = KInputDialog::getText ( i18n("New name"),i18n("Enter new name for profile:"), oldName, &ok,this);
+	QString newName = KInputDialog::getText ( i18n("New Name"),i18n("Enter new name for profile:"), oldName, &ok,this);
 
 	if (ok)
 	{
@@ -1644,7 +1644,7 @@ void ProfileWidget::additionalNetworkRoutesToggled(bool)
 
 void ProfileWidget::addNetworkRouteClicked()
 {
-	AddNetworkRouteDialog dlg(this, i18n("Add network route..."));
+	AddNetworkRouteDialog dlg(this, i18n("Add Network Route..."));
 	if (dlg.exec())
 	{
 		NetworkListView->insertItem( new QListViewItem(NetworkListView, dlg.getNetwork(),dlg.getNetmask()));
