@@ -19,7 +19,7 @@
 ***************************************************************************/
 #include "vpnaccountdata.h"
 
-VpnAccountData::VpnAccountData( ConnectionType ConnType, QString Name)
+VpnAccountData::VpnAccountData( ConnectionType ConnType,const QString& Name)
 {
 	this->RemoteNet = "";
 	this->CertPath = "";
@@ -106,461 +106,473 @@ VpnAccountData::VpnAccountData( ConnectionType ConnType, QString Name)
 	SpecialServerCertificate="";
 	useSpecialServerCertificate=false;
 	TunnelDeviceType="tun";
-
+	keepDefaultRoute = false;
+	allowEmptyGroupPassword=false;
 }
 
 
 VpnAccountData::~VpnAccountData()
 {}
 
-QString VpnAccountData::getName()
+QString VpnAccountData::getName() const
 {
 	return Name;
 }
 
-VpnAccountData::ConnectionType VpnAccountData::getConnectionType()
+VpnAccountData::ConnectionType VpnAccountData::getConnectionType() const
 {
 	return connectiontype;
 }
 
-QString VpnAccountData::getGateway()
+QString VpnAccountData::getGateway() const
 {
 	return Gateway;
 }
 
-QString VpnAccountData::getID()
+QString VpnAccountData::getID() const 
 {
 	return ID;
 }
 
-QString VpnAccountData::getTunnelDeviceType()
+QString VpnAccountData::getTunnelDeviceType() const
 {
 	return TunnelDeviceType;
 }
 
-QString VpnAccountData::getUserName()
+QString VpnAccountData::getUserName() const 
 {
 	return Username;
 }
 
-QString VpnAccountData::getUserPassword()
+QString VpnAccountData::getUserPassword() const
 {
 	return UserPassword;
 }
 
-bool VpnAccountData::getSaveUserPassword()
+bool VpnAccountData::getSaveUserPassword() const
 {
 	return saveUserPassword;
 }
 
-bool VpnAccountData::getSavePsk()
+bool VpnAccountData::getSavePsk() const
 {
 	return savePsk;
 }
 
-QString VpnAccountData::getIkeGroup()
+QString VpnAccountData::getIkeGroup() const
 {
 	return IkeGroup;
 }
 
-QString VpnAccountData::getPerfectForwardSecrety()
+QString VpnAccountData::getPerfectForwardSecrety() const
 {
 	return PerfectForwardSecrecy;
 }
 
-QString VpnAccountData::getNtDomainName()
+QString VpnAccountData::getNtDomainName() const
 {
 	return NtDomainName;
 }
 
-QString VpnAccountData::getApplicationVersion()
+QString VpnAccountData::getApplicationVersion() const
 {
 	return ApplicationVersion;
 }
 
-bool VpnAccountData::getUseSingleDes()
+bool VpnAccountData::getUseSingleDes() const
 {
 	return useSingleDes;
 
 }
 
-bool VpnAccountData::getUseIkeGroup()
+bool VpnAccountData::getUseIkeGroup() const
 {
 	return useIkeGroup;
 }
 
-bool VpnAccountData::getUsePerfectForwardSecrety()
+bool VpnAccountData::getUsePerfectForwardSecrety() const
 {
 	return usePerfectForwardSecrety;
 }
 
-bool VpnAccountData::getUseNtDomainName()
+bool VpnAccountData::getUseNtDomainName() const
 {
 	return useNtDomainName;
 }
 
-bool VpnAccountData::getUseApplicationVersion()
+bool VpnAccountData::getUseApplicationVersion() const
 {
 	return useApplicationVersion;
 }
-bool VpnAccountData::getUseLocalPort()
+bool VpnAccountData::getUseLocalPort() const
 {
 	return useLocalPort;
 }
 
-bool VpnAccountData::getUseAdvancedSettings()
+bool VpnAccountData::getUseAdvancedSettings() const
 {
 	return useAdvancedSettings;
 }
 
-bool VpnAccountData::getUseGlobalIpsecSecret()
+bool VpnAccountData::getUseGlobalIpsecSecret() const
 {
 	return useGlobalIpsecSecret;
 }
 
-int VpnAccountData::getLocalPort()
+int VpnAccountData::getLocalPort() const
 {
 	return LocalPort;
 }
 
-QString VpnAccountData::getRemoteNet()
+QString VpnAccountData::getRemoteNet() const
 {
 	return RemoteNet;
 }
 
-QString VpnAccountData::getPreSharedKey()
+QString VpnAccountData::getPreSharedKey() const
 {
 	return PreSharedKey;
 }
 
-QString VpnAccountData::getX509Certificate()
+QString VpnAccountData::getX509Certificate() const
 {
 	return x509Certificate;
 }
 
-QString VpnAccountData::getCaCertificate()
+QString VpnAccountData::getCaCertificate() const
 {
 	return CaCertificate;
 }
 
-QString VpnAccountData::getNetworkDevice()
+QString VpnAccountData::getNetworkDevice() const
 {
-	if (NetworkDevice)
+	if (NetworkDevice != QString::null)
 		return NetworkDevice;
 	else
-		return QString("");
+		return "";
 }
 
-QString VpnAccountData::getCertPath()
+QString VpnAccountData::getCertPath() const
 {
 	return CertPath;
 }
 
-VpnAccountData::AuthenticationType VpnAccountData::getAuthType()
+VpnAccountData::AuthenticationType VpnAccountData::getAuthType() const
 {
 	return authtype;
 }
 
-bool VpnAccountData::getDoPingIP()
+bool VpnAccountData::getDoPingIP() const
 {
 	return doPingIP;
 }
 
-QString VpnAccountData::getPingHostIP()
+QString VpnAccountData::getPingHostIP() const
 {
 	return pingHostIP;
 }
 
-QString VpnAccountData::getPrivateKeyPass()
+QString VpnAccountData::getPrivateKeyPass() const
 {
 	return PrivateKeyPass;
 }
 
-QString VpnAccountData::getPrivateKey()
+QString VpnAccountData::getPrivateKey() const
 {
 	return PrivateKey;
 }
 
-bool VpnAccountData::getUseSpecialRemoteID()
+bool VpnAccountData::getUseSpecialRemoteID() const
 {
 	return useSpecialRemoteID;
 }
 
-QString VpnAccountData::getSpecialRemoteID()
+QString VpnAccountData::getSpecialRemoteID() const
 {
 	return SpecialRemoteID;
 }
 
-bool VpnAccountData::getUseUdp()
+bool VpnAccountData::getUseUdp() const
 {
 	return useUdp;
 }
 
-bool VpnAccountData::getUseUdpPort()
+bool VpnAccountData::getUseUdpPort() const
 {
 	return useUdpPort;
 }
 
-int VpnAccountData::getUdpPort()
+int VpnAccountData::getUdpPort() const
 {
 	return UdpPort;
 }
 
-bool VpnAccountData::getUseDnsServer()
+bool VpnAccountData::getUseDnsServer() const
 {
 	return useDnsServer;
 }
 
-QString VpnAccountData::getDnsServer()
+QString VpnAccountData::getDnsServer() const
 {
 	return DnsServer;
 }
 
-bool VpnAccountData::getUseGetDnsFromPeer()
+bool VpnAccountData::getUseGetDnsFromPeer() const
 {
 	return useGetDnsFromPeer;
 }
 
-bool VpnAccountData::getRefuse40BitEncryption()
+bool VpnAccountData::getRefuse40BitEncryption() const
 {
 	return refuse40BitEncryption;
 }
 
-bool VpnAccountData::getRefuse128BitEncryption()
+bool VpnAccountData::getRefuse128BitEncryption() const
 {
 	return refuse128BitEncryption;
 }
 
-bool VpnAccountData::getAllowStatefulMode()
+bool VpnAccountData::getAllowStatefulMode() const
 {
 	return allowStatefulMode;
 }
 
-bool VpnAccountData::getRequireMppe()
+bool VpnAccountData::getRequireMppe() const
 {
 	return requireMppe;
 }
 
-bool VpnAccountData::getRefuseEap()
+bool VpnAccountData::getRefuseEap() const
 {
 	return refuseEap;
 }
 
-bool VpnAccountData::getUseNoIpDefault()
+bool VpnAccountData::getUseNoIpDefault() const
 {
 	return useNoIpDefault;
 }
 
-bool VpnAccountData::getDisableMPPEComp()
+bool VpnAccountData::getDisableMPPEComp() const
 {
 	return disableMPPEComp;
 }
 
-bool VpnAccountData::getUseSpecialServerCertificate()
+bool VpnAccountData::getUseSpecialServerCertificate() const
 {
 	return useSpecialServerCertificate;
 }
 
-QString VpnAccountData::getSpecialServerCertificate()
+QString VpnAccountData::getSpecialServerCertificate() const
 {
 	return SpecialServerCertificate;
 }
 
-QString VpnAccountData::getLocalVirtualIP()
+QString VpnAccountData::getLocalVirtualIP() const
 {
 	return LocalVirtualIP;
 }
-QString VpnAccountData::getRemoteVirtualIP()
+QString VpnAccountData::getRemoteVirtualIP() const
 {
 	return RemoteVirtualIP;
 }
 
-QString VpnAccountData::getPreSharedKeyFile()
+QString VpnAccountData::getPreSharedKeyFile() const
 {
 	return PreSharedKeyFile;
 }
 
-bool VpnAccountData::getExecuteCmdBeforeConnect()
+bool VpnAccountData::getExecuteCmdBeforeConnect() const 
 {
 	return executeCmdBeforeConnect;
 }
 
-bool VpnAccountData::getExecuteCmdAfterConnect()
+bool VpnAccountData::getExecuteCmdAfterConnect() const
 {
 	return executeCmdAfterConnect;
 }
 
-bool VpnAccountData::getExecuteCmdBeforeDisconnect()
+bool VpnAccountData::getExecuteCmdBeforeDisconnect() const
 {
 	return executeCmdBeforeDisconnect;
 }
 
-bool VpnAccountData::getExecuteCmdAfterDisconnect()
+bool VpnAccountData::getExecuteCmdAfterDisconnect() const
 {
 	return executeCmdAfterDisconnect;
 }
 
-QString VpnAccountData::getCommandBeforeConnect()
+QString VpnAccountData::getCommandBeforeConnect() const
 {
 	return CommandBeforeConnect;
 }
 
-QString VpnAccountData::getCommandAfterConnect()
+QString VpnAccountData::getCommandAfterConnect() const
 {
 	return CommandAfterConnect;
 }
 
-QString VpnAccountData::getCommandBeforeDisconnect()
+QString VpnAccountData::getCommandBeforeDisconnect() const
 {
 	return CommandBeforeDisconnect;
 }
 
-QString VpnAccountData::getCommandAfterDisconnect()
+QString VpnAccountData::getCommandAfterDisconnect() const
 {
 	return CommandAfterDisconnect;
 }
 
-bool VpnAccountData::getUseNoBsdComp()
+bool VpnAccountData::getUseNoBsdComp() const
 {
 	return useNoBsdComp;
 }
 
-bool VpnAccountData::getUseNoDeflate()
+bool VpnAccountData::getUseNoDeflate() const
 {
 	return useNoDeflate;
 }
 
-bool VpnAccountData::getSetDefaultRoute()
+bool VpnAccountData::getSetDefaultRoute() const
 {
 	return setDefaultRoute;
 }
 
-bool VpnAccountData::getReplaceDefaultRoute()
+bool VpnAccountData::getReplaceDefaultRoute() const
 {
 	return replaceDefaultRoute;
 }
 
-bool VpnAccountData::getUseMtu()
+bool VpnAccountData::getUseMtu() const
 {
 	return useMtu;
 }
 
-int VpnAccountData::getMtu()
+int VpnAccountData::getMtu() const
 {
 	return Mtu;
 }
 
-bool VpnAccountData::getUseVirtualIP()
+bool VpnAccountData::getUseVirtualIP() const
 {
 	return useVirtualIP;
 }
 
-QString VpnAccountData::getVirtualIP()
+QString VpnAccountData::getVirtualIP() const
 {
 	return VirtualIP;
 }
 
-bool VpnAccountData::getPskIsInFile()
+bool VpnAccountData::getPskIsInFile() const
 {
 	return PskIsInFile;
 }
 
-bool VpnAccountData::getUseAdditionalNetworkRoutes()
+bool VpnAccountData::getUseAdditionalNetworkRoutes() const
 {
 	return useAdditionalNetworkRoutes;
 }
 
-QStringList VpnAccountData::getAdditionalNetworkRoutes()
+QStringList VpnAccountData::getAdditionalNetworkRoutes() const
 {
 	return AdditionalNetworkRoutes;
 }
 
-QString VpnAccountData::getHashAlgo()
+QString VpnAccountData::getHashAlgo() const
 {
 	return HashAlgo;
 }
 
-bool VpnAccountData::getUseUserdefinedPort()
+bool VpnAccountData::getUseUserdefinedPort() const
 {
 	return useUserdefinedPort;
 }
 
-int VpnAccountData::getUserdefinedPort()
+int VpnAccountData::getUserdefinedPort() const
 {
 	return UserdefinedPort;
 }
 
-bool VpnAccountData::getKeepDefaultRoute()
+bool VpnAccountData::getKeepDefaultRoute() const
 {
 	return keepDefaultRoute;
 }
 
-QString VpnAccountData::getDescription()
+QString VpnAccountData::getDescription() const
 {
 	return Description;
 }
 
-QString VpnAccountData::getNsCertType()
+QString VpnAccountData::getNsCertType() const
 {
 	return NsCertType;
 }
 
-bool VpnAccountData::getUseNsCertType()
+bool VpnAccountData::getUseNsCertType() const
 {
 	return useNsCertType;
 }
 
-bool VpnAccountData::getUseConnectionStatusCheck()
+bool VpnAccountData::getUseConnectionStatusCheck() const
 {
 	return useConnectionStatusCheck;
 }
 
-int VpnAccountData::getConnectionStatusCheckSuccessCount()
+int VpnAccountData::getConnectionStatusCheckSuccessCount() const
 {
 	return connectionStatusCheckSuccessCount;
 }
 
-int VpnAccountData::getConnectionStatusInterval()
+int VpnAccountData::getConnectionStatusInterval() const
 {
 	return connectionStatusInterval;
 }
 
-bool VpnAccountData::getDoReconnectAfterConnectionLost()
+bool VpnAccountData::getDoReconnectAfterConnectionLost() const
 {
 	return doReconnectAfterConnectionLost;
 }
 
-bool VpnAccountData::getDisableLzoCompression()
+bool VpnAccountData::getDisableLzoCompression() const
 {
 	return disableLzoCompression;
 }
 
+bool VpnAccountData::getAuthWithUsernameAndPassword() const
+{
+		return AuthWithUsernameAndPassword;
+}
+
+bool VpnAccountData::getAllowEmptyGroupPassword() const
+{
+	return allowEmptyGroupPassword;
+}
+
+
 /* set methods */
 void VpnAccountData::setConnectionType( ConnectionType type )
 {
 	this->connectiontype = type;
 }
 
-void VpnAccountData::setName( QString Name )
+void VpnAccountData::setName( const QString &Name )
 {
 	this->Name = Name;
 }
 
-void VpnAccountData::setGateway( QString Gateway )
+void VpnAccountData::setGateway( const QString &Gateway )
 {
 	this->Gateway = Gateway;
 }
-void VpnAccountData::setID( QString ID )
+void VpnAccountData::setID( const QString &ID )
 {
 	this->ID = ID;
 }
 
-void VpnAccountData::setUserName( QString Username )
+void VpnAccountData::setUserName( const QString &Username )
 {
 	this->Username = Username;
 }
 
-void VpnAccountData::setUserPassword( QString UserPassword )
+void VpnAccountData::setUserPassword( const QString& UserPassword )
 {
 	this->UserPassword = UserPassword;
 }
@@ -575,22 +587,22 @@ void VpnAccountData::setSavePsk( bool savePsk )
 	this->savePsk = savePsk;
 }
 
-void VpnAccountData::setIkeGroup( QString IkeGroup )
+void VpnAccountData::setIkeGroup( const QString &IkeGroup )
 {
 	this->IkeGroup = IkeGroup;
 }
 
-void VpnAccountData::setPerfectForwardSecrety( QString PerfectForwardSecrecy )
+void VpnAccountData::setPerfectForwardSecrety( const QString &PerfectForwardSecrecy )
 {
 	this->PerfectForwardSecrecy = PerfectForwardSecrecy;
 }
 
-void VpnAccountData::setNtDomainName( QString Name )
+void VpnAccountData::setNtDomainName( const QString& Name )
 {
 	this->NtDomainName = Name;
 }
 
-void VpnAccountData::setApplicationVersion( QString version )
+void VpnAccountData::setApplicationVersion( const QString& version )
 {
 	this->ApplicationVersion = version;
 }
@@ -640,32 +652,32 @@ void VpnAccountData::setLocalPort( int port )
 	this->LocalPort = port;
 }
 
-void VpnAccountData::setRemoteNet( QString RemoteNet )
+void VpnAccountData::setRemoteNet( const QString& RemoteNet )
 {
 	this->RemoteNet = RemoteNet;
 }
 
-void VpnAccountData::setPreSharedKey( QString PreSharedKey )
+void VpnAccountData::setPreSharedKey( const QString& PreSharedKey )
 {
 	this->PreSharedKey = PreSharedKey;
 }
 
-void VpnAccountData::setX509Certificate( QString x509Certificate )
+void VpnAccountData::setX509Certificate( const QString& x509Certificate )
 {
 	this->x509Certificate = x509Certificate;
 }
 
-void VpnAccountData::setCaCertificate( QString CaCertificate )
+void VpnAccountData::setCaCertificate( const QString& CaCertificate )
 {
 	this->CaCertificate = CaCertificate;
 }
 
-void VpnAccountData::setNetworkDevice( QString NetworkDevice )
+void VpnAccountData::setNetworkDevice( const QString& NetworkDevice )
 {
 	this->NetworkDevice = NetworkDevice;
 }
 
-void VpnAccountData::setCertPath( QString CertPath )
+void VpnAccountData::setCertPath( const QString& CertPath )
 {
 	this->CertPath = CertPath;
 }
@@ -680,17 +692,17 @@ void VpnAccountData::setDoPingIP(bool doPingIP)
 	this->doPingIP=doPingIP;
 }
 
-void VpnAccountData::setPingHostIP(QString pingHostIP)
+void VpnAccountData::setPingHostIP(const QString& pingHostIP)
 {
 	this->pingHostIP = pingHostIP;
 }
 
-void VpnAccountData::setPrivateKeyPass(QString PrivateKeyPass)
+void VpnAccountData::setPrivateKeyPass(const QString& PrivateKeyPass)
 {
 	this->PrivateKeyPass = PrivateKeyPass;
 }
 
-void VpnAccountData::setPrivateKey(QString PrivateKey)
+void VpnAccountData::setPrivateKey(const QString& PrivateKey)
 {
 	this->PrivateKey = PrivateKey;
 }
@@ -700,7 +712,7 @@ void VpnAccountData::setUseSpecialRemoteID(bool useSpecialRemoteID)
 	this->useSpecialRemoteID = useSpecialRemoteID;
 }
 
-void VpnAccountData::setSpecialRemoteID(QString SpecialRemoteID)
+void VpnAccountData::setSpecialRemoteID(const QString& SpecialRemoteID)
 {
 	this->SpecialRemoteID = SpecialRemoteID;
 }
@@ -725,7 +737,7 @@ void VpnAccountData::setUseDnsServer(bool useDnsServer )
 	this->useDnsServer = useDnsServer;
 }
 
-void VpnAccountData::setDnsServer(QString DnsServer )
+void VpnAccountData::setDnsServer(const QString& DnsServer )
 {
 	this->DnsServer = DnsServer;
 }
@@ -770,17 +782,17 @@ void VpnAccountData::setDisableMPPEComp(bool disableMPPEComp )
 	this->disableMPPEComp = disableMPPEComp;
 }
 
-void VpnAccountData::setLocalVirtualIP( QString LocalVirtualIP )
+void VpnAccountData::setLocalVirtualIP( const QString& LocalVirtualIP )
 {
 	this->LocalVirtualIP = LocalVirtualIP;
 }
 
-void VpnAccountData::setRemoteVirtualIP( QString RemoteVirtualIP )
+void VpnAccountData::setRemoteVirtualIP( const QString& RemoteVirtualIP )
 {
 	this->RemoteVirtualIP = RemoteVirtualIP;
 }
 
-void VpnAccountData::setPreSharedKeyFile( QString PreSharedKeyFile)
+void VpnAccountData::setPreSharedKeyFile( const QString& PreSharedKeyFile)
 {
 	this->PreSharedKeyFile = PreSharedKeyFile;
 }
@@ -805,22 +817,22 @@ void VpnAccountData::setExecuteCmdAfterDisconnect( bool executeCmdAfterDisconnec
 	this->executeCmdAfterDisconnect = executeCmdAfterDisconnect;
 }
 
-void VpnAccountData::setCommandBeforeConnect(QString CommandBeforeConnect)
+void VpnAccountData::setCommandBeforeConnect(const QString& CommandBeforeConnect)
 {
 	this->CommandBeforeConnect = CommandBeforeConnect;
 }
 
-void VpnAccountData::setCommandAfterConnect(QString CommandAfterConnect)
+void VpnAccountData::setCommandAfterConnect(const QString& CommandAfterConnect)
 {
 	this->CommandAfterConnect = CommandAfterConnect;
 }
 
-void VpnAccountData::setCommandBeforeDisconnect(QString CommandBeforeDisconnect)
+void VpnAccountData::setCommandBeforeDisconnect(const QString& CommandBeforeDisconnect)
 {
 	this->CommandBeforeDisconnect = CommandBeforeDisconnect;
 }
 
-void VpnAccountData::setCommandAfterDisconnect(QString CommandAfterDisconnect)
+void VpnAccountData::setCommandAfterDisconnect(const QString& CommandAfterDisconnect)
 {
 	this->CommandAfterDisconnect = CommandAfterDisconnect;
 }
@@ -860,7 +872,7 @@ void VpnAccountData::setUseVirtualIP(bool useVirtualIP )
 	this->useVirtualIP = useVirtualIP;
 }
 
-void VpnAccountData::setVirtualIP(QString VirtualIP )
+void VpnAccountData::setVirtualIP(const QString& VirtualIP )
 {
 	this->VirtualIP = VirtualIP;
 }
@@ -885,17 +897,17 @@ void VpnAccountData::setUseSpecialServerCertificate(bool useSpecialServerCertifi
 	this->useSpecialServerCertificate = useSpecialServerCertificate;
 }
 
-void VpnAccountData::setSpecialServerCertificate(QString SpecialServerCertificate)
+void VpnAccountData::setSpecialServerCertificate(const QString& SpecialServerCertificate)
 {
 	this->SpecialServerCertificate = SpecialServerCertificate;
 }
 
-void VpnAccountData::setHashAlgo(QString HashAlgo)
+void VpnAccountData::setHashAlgo(const QString& HashAlgo)
 {
 	this->HashAlgo = HashAlgo;
 }
 
-void VpnAccountData::setTunnelDeviceType(QString TunnelDeviceType)
+void VpnAccountData::setTunnelDeviceType(const QString& TunnelDeviceType)
 {
 	this->TunnelDeviceType = TunnelDeviceType;
 }
@@ -914,12 +926,12 @@ void VpnAccountData::setKeepDefaultRoute(bool keepDefaultRoute)
 	this->keepDefaultRoute = keepDefaultRoute;
 }
 
-void VpnAccountData::setDescription(QString Description)
+void VpnAccountData::setDescription(const QString& Description)
 {
 	this->Description = Description;
 }
 
-void VpnAccountData::setNsCertType(QString NsCertType)
+void VpnAccountData::setNsCertType(const QString& NsCertType)
 {
 	this->NsCertType = NsCertType;
 }
@@ -954,3 +966,12 @@ void VpnAccountData::setDisableLzoCompression(bool disableLzoCompression )
 	this->disableLzoCompression = disableLzoCompression;
 }
 
+void VpnAccountData::setAuthWithUsernameAndPassword(bool AuthWithUsernameAndPassword )
+{
+		this->AuthWithUsernameAndPassword = AuthWithUsernameAndPassword;
+}
+
+void VpnAccountData::setAllowEmptyGroupPassword( bool allowEmptyGroupPassword )
+{
+	this->allowEmptyGroupPassword = allowEmptyGroupPassword;
+}
